.. _pyisbn-label:

.. module:: pyisbn

``pyisbn`` - A module for working with 10- and 13-digit ISBNs
=============================================================

:mod:`pyisbn` is a `GPL v3`_ licensed module for working with various book
identification numbers.  It includes functions for conversion, verification and
generation of checksums.  It also includes basic classes for representing ISBNs
as objects.

:Git repository:  https://github.com/JNRowe/pyisbn/
:Issue tracker:  https://github.com/JNRowe/pyisbn/issues/
:Contributors:  https://github.com/JNRowe/pyisbn/contributors/

.. _GPL v3: http://www.gnu.org/licenses/

Contents
--------

.. toctree::
   :maxdepth: 2

   install
   api/index
   faq
   fun
   alternatives
   release

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
